import IORedis, { Cluster } from 'ioredis';
export class Redis {
    client;
    getAsync;
    constructor(options, isCluster, clusterNodes) {
        if (isCluster) {
            this.client = new Cluster(clusterNodes, options);
        }
        else {
            this.client = new IORedis(options);
        }
    }
    async set(key, data) {
        if (data.maxAge) {
            await this.client.set(key, JSON.stringify(data), 'EX', data.maxAge);
            return data;
        }
        await this.client.set(key, JSON.stringify(data));
        return data;
    }
    async get(key) {
        const cacheString = await this.client.get(key);
        return JSON.parse(cacheString);
    }
    async drop(key) {
        await this.client.del(key);
        return true;
    }
    async invalidate(keys) {
        (keys || []).forEach(key => this.client.del(key));
        return true;
    }
}
//# sourceMappingURL=ioredis-engine.js.map