import IORedis, { Cluster, ClusterNode, ClusterOptions, Redis as RedisInterface, RedisOptions } from 'ioredis';
import { ICacheEngine } from '../interfaces';

export class Redis implements ICacheEngine {
    private client: RedisInterface | Cluster;
    private getAsync;

    constructor(options: RedisOptions | ClusterOptions, isCluster?: boolean, clusterNodes?: ClusterNode[]) {
        if (isCluster) {
            this.client = new Cluster(clusterNodes, options);
        } else {
            this.client = new IORedis(options);
        }
    }

    public async set(key: string, data: any) {
        if (data.maxAge) {
            await this.client.set(key, JSON.stringify(data), 'EX', data.maxAge);
            return data;
        }
        await this.client.set(key, JSON.stringify(data));
        return data;
    }

    public async get(key: string) {
        const cacheString = await this.client.get(key);
        return JSON.parse(cacheString);
    }

    public async drop(key: string) {
        await this.client.del(key);
        return true;
    }

    public async invalidate(keys?: string[]) {
        (keys || []).forEach(key => this.client.del(key));
        return true;
    }
}
